from setuptools import setup, find_packages

setup(
    name="ufsdk",
    version="0.1.0",
    description="UCloud UFile SDK for Python",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Ben",
    author_email="benluu.fpt@gmail.com",
    url="https://github.com/benakaben10/ufsdk",  # optional
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)